lilypondfiletools.MIDIBlock
===========================

.. abjad-lineage:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock

.. autoclass:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.storage_format
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.is_formatted_when_empty
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.append
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.count
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.extend
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.index
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.insert
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.pop
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.remove
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.reverse
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.sort
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__add__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__contains__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__delitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__delslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__getslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__iadd__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__imul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__iter__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__len__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__mul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__repr__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__reversed__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__rmul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__setitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.MIDIBlock.MIDIBlock.MIDIBlock.__setslice__
   :noindex:
